Type: Package
Package: ArchaeoPhases
Title: Post-Processing of Markov Chain Monte Carlo Simulations for
        Chronological Modelling
Version: 2.1.1
Authors@R: c(
    person("Anne", "Philippe", , "anne.philippe@univ-nantes.fr", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-5331-5087")),
    person("Marie-Anne", "Vibet", role = "aut",
           comment = c(ORCID = "0000-0003-4003-3141")),
    person("Nicolas", "Frerebeau", , "nicolas.frerebeau@u-bordeaux-montaigne.fr", role = "aut",
           comment = c(ORCID = "0000-0001-5759-4944")),
    person("Thomas S.", "Dye", role = "ctb",
           comment = c(ORCID = "0000-0001-8116-782X")),
    person("Nantes Université", role = "fnd",
           comment = c(ROR = "03gnr7b55")),
    person("Université Bordeaux Montaigne", role = "fnd",
           comment = c(ROR = "03pbgwk21")),
    person("CNRS", role = "fnd",
           comment = c(ROR = "02feahw73"))
  )
Maintainer: Anne Philippe <anne.philippe@univ-nantes.fr>
Description: Statistical analysis of archaeological dates and groups of
    dates. This package allows to post-process Markov Chain Monte Carlo
    (MCMC) simulations from 'ChronoModel' <https://chronomodel.com/>,
    'Oxcal' <https://c14.arch.ox.ac.uk/oxcal.html> or 'BCal'
    <https://bcal.shef.ac.uk/>. It provides functions for the study of
    rhythms of the long term from the posterior distribution of a series
    of dates (tempo and activity plot). It also allows the estimation and
    visualization of time ranges from the posterior distribution of groups
    of dates (e.g. duration, transition and hiatus between successive
    phases) as described in Philippe and Vibet (2020)
    <doi:10.18637/jss.v093.c01>.
License: GPL (>= 3)
URL: https://ArchaeoStat.github.io/ArchaeoPhases/,
        https://github.com/ArchaeoStat/ArchaeoPhases
BugReports: https://github.com/ArchaeoStat/ArchaeoPhases/issues
Depends: R (>= 3.5), aion (>= 1.7.0)
Imports: arkhe (>= 1.11.0), graphics, grDevices, methods, stats, tools,
        utils
Suggests: ArchaeoData, coda, fontquiver, knitr, rmarkdown, rsvg,
        svglite, tinysnapshot, tinytest
VignetteBuilder: knitr
Additional_repositories: https://archaeostat.r-universe.dev
Encoding: UTF-8
LazyData: true
X-schema.org-applicationCategory: Archaeological Science
X-schema.org-keywords: markov-chain, bayesian-statistics,
        geochronology, radiocarbon-dates, archaeology,
        archaeological-science, r-package
Collate: 'AllClasses.R' 'AllGenerics.R' 'ArchaeoPhases-defunct.R'
        'ArchaeoPhases-deprecated.R' 'ArchaeoPhases-internal.R'
        'ArchaeoPhases-package.R' 'activity.R' 'allen-mcmc.R'
        'allen-relations.R' 'bind.R' 'boundaries.R' 'coerce.R' 'data.R'
        'depth.R' 'duration.R' 'elapse.R' 'events.R' 'hiatus.R'
        'interpolate.R' 'interval.R' 'mutators.R' 'occurrence.R'
        'phases.R' 'plot.R' 'read.R' 'sensitivity.R' 'show.R' 'sort.R'
        'subset.R' 'summary.R' 'tempo.R' 'test.R' 'transition.R'
        'validate.R' 'zzz.R'
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-07-01 13:47:35 UTC; annephilippe
Author: Anne Philippe [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-5331-5087>),
  Marie-Anne Vibet [aut] (ORCID: <https://orcid.org/0000-0003-4003-3141>),
  Nicolas Frerebeau [aut] (ORCID:
    <https://orcid.org/0000-0001-5759-4944>),
  Thomas S. Dye [ctb] (ORCID: <https://orcid.org/0000-0001-8116-782X>),
  Nantes Université [fnd] (ROR: <https://ror.org/03gnr7b55>),
  Université Bordeaux Montaigne [fnd] (ROR: <https://ror.org/03pbgwk21>),
  CNRS [fnd] (ROR: <https://ror.org/02feahw73>)
Repository: CRAN
Date/Publication: 2026-07-02 00:42:03 UTC
Built: R 4.5.2; ; 2026-07-02 02:39:09 UTC; unix
