# Generated by roxygen2: do not edit by hand

S3method(as.array,PhasesMCMC)
S3method(as.data.frame,ActivityEvents)
S3method(as.data.frame,CumulativeEvents)
S3method(as.data.frame,OccurrenceEvents)
S3method(as.data.frame,TimeRange)
S3method(as.matrix,MCMC)
S3method(plot,ActivityEvents)
S3method(plot,AgeDepthModel)
S3method(plot,CumulativeEvents)
S3method(plot,MCMC)
S3method(plot,PhasesMCMC)
export(AgeDepth)
export(CreateMinMaxGroup)
export(CredibleInterval)
export(DatesHiatus)
export(MarginalPlot)
export(MarginalProba)
export(MarginalStatistics)
export(MultiCredibleInterval)
export(MultiDatesPlot)
export(MultiHPD)
export(MultiMarginalPlot)
export(MultiPhasePlot)
export(MultiPhaseTimeRange)
export(MultiPhasesGap)
export(MultiPhasesTransition)
export(MultiSuccessionPlot)
export(OccurrencePlot)
export(PhaseDurationPlot)
export(PhasePlot)
export(PhaseStatistics)
export(PhaseTimeRange)
export(PhasesGap)
export(PhasesTransition)
export(SuccessionPlot)
export(TempoActivityPlot)
export(TempoPlot)
export(allen_analyze)
export(allen_illustrate)
export(allen_relation_code)
export(allen_relation_concurrent)
export(allen_relation_distinct)
export(allen_relation_string)
export(credible_interval)
export(dates_hiatus)
export(estimate_range)
export(marginal_plot)
export(marginal_statistics)
export(multi_credible_interval)
export(multi_dates_plot)
export(multi_hpd)
export(multi_marginal_plot)
export(multi_marginal_statistics)
export(occurrence_plot)
export(phases_gap)
export(tempo_activity_plot)
export(tempo_plot)
export(undated_sample)
exportMethods("[")
exportMethods("names<-")
exportMethods(activity)
exportMethods(allen_complement)
exportMethods(allen_composition)
exportMethods(allen_converse)
exportMethods(allen_intersect)
exportMethods(allen_joint_concurrency)
exportMethods(allen_observe)
exportMethods(allen_observe_frequency)
exportMethods(allen_relation)
exportMethods(allen_union)
exportMethods(as.array)
exportMethods(as.data.frame)
exportMethods(as.matrix)
exportMethods(as_coda)
exportMethods(as_events)
exportMethods(as_phases)
exportMethods(boundaries)
exportMethods(bury)
exportMethods(cbind2)
exportMethods(duration)
exportMethods(elapse)
exportMethods(hiatus)
exportMethods(interpolate)
exportMethods(interval_credible)
exportMethods(interval_hdr)
exportMethods(is_original)
exportMethods(names)
exportMethods(occurrence)
exportMethods(older)
exportMethods(phases)
exportMethods(plot)
exportMethods(predict)
exportMethods(read_bcal)
exportMethods(read_chronomodel_events)
exportMethods(read_chronomodel_phases)
exportMethods(read_oxcal)
exportMethods(sensitivity)
exportMethods(sort)
exportMethods(sort.list)
exportMethods(summary)
exportMethods(tempo)
exportMethods(transition)
import(aion)
import(arkhe)
import(methods)
importClassesFrom(aion,RataDie)
importClassesFrom(aion,TimeIntervals)
importClassesFrom(aion,TimeSeries)
