## Options for snapshot tests
options(tinysnapshot_os = "Linux")
options(tinysnapshot_device = "svglite")
options(tinysnapshot_height = 7) # inches
options(tinysnapshot_width = 7)
options(tinysnapshot_tol = 1000) # pixels
options(tinysnapshot_device_args = list(user_fonts = fontquiver::font_families("Liberation")))
